@@ -24,7 +24,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
-$SCRIPTSDIR = "";
+$SCRIPTSDIR = "/opt/kde/share/apps/knetworkconf/backends";
 if ($SCRIPTSDIR =~ /^@scriptsdir[@]/)
 {
     $SCRIPTSDIR = ".";
